@@ -17,6 +17,7 @@ module Language.Preprocessor.Cpphs.Options
   , parseOptions
   , defaultCpphsOptions
   , defaultBoolOptions
+  , trailing
   ) where
 
 import Data.Maybe
@@ -28,7 +29,7 @@ data CpphsOptions = CpphsOptions
     , outfiles	:: [FilePath]
     , defines	:: [(String,String)]
     , includes	:: [String]
-    , preInclude:: [FilePath]	-- ^ Files to #include before anything else
+    , preInclude:: [FilePath]	-- ^ Files to \#include before anything else
     , boolopts	:: BoolOptions
     }
 
@@ -42,9 +43,9 @@ defaultCpphsOptions = CpphsOptions { infiles = [], outfiles = []
 -- | Options representable as Booleans.
 data BoolOptions = BoolOptions
     { macros	:: Bool  -- ^ Leave \#define and \#undef in output of ifdef?
-    , locations	:: Bool	 -- ^ Place #line droppings in output?
-    , hashline	:: Bool	 -- ^ Write #line or {-# LINE #-} ?
-    , pragma	:: Bool  -- ^ Keep #pragma in final output?
+    , locations	:: Bool	 -- ^ Place \#line droppings in output?
+    , hashline	:: Bool	 -- ^ Write \#line or {-\# LINE \#-} ?
+    , pragma	:: Bool  -- ^ Keep \#pragma in final output?
     , stripEol	:: Bool  -- ^ Remove C eol (\/\/) comments everywhere?
     , stripC89	:: Bool  -- ^ Remove C inline (\/**\/) comments everywhere?
     , lang	:: Bool  -- ^ Lex input as Haskell code?
@@ -110,6 +111,9 @@ rawOption xs | "--include="`isPrefixOf`xs
             = Just $ PreInclude (drop 10 xs)
 rawOption _ = Nothing
 
+-- | Trim trailing elements of the second list that match any from
+--   the first list.  Typically used to remove trailing forward\/back
+--   slashes from a directory path.
 trailing :: (Eq a) => [a] -> [a] -> [a]
 trailing xs = reverse . dropWhile (`elem`xs) . reverse
 
